@@ -2,7 +2,7 @@
 package MooseX::Getopt::Usage;
 
 use 5.010;
-our $VERSION = '0.12';
+our $VERSION = '0.14';
 
 use Moose::Role;
 use Try::Tiny;
@@ -72,20 +72,20 @@ around new_with_options => sub {
         return $self;
     }
     catch {
-        when (
+        if (
             /Attribute \((\w+)\) does not pass the type constraint because: (.*?) at/
         ) {
             $class->getopt_usage( exit => 1, err => "Invalid '$1' : $2" );
         }
-        when (/Attribute \((\w+)\) is required /) {
+        elsif (/Attribute \((\w+)\) is required /) {
             $class->getopt_usage( exit => 2, err => "Required option missing: $1" );
         }
-        when (/^Unknown option:|^Value .*? for option |Option .* does not take an argument/) {
+        elsif (/^Unknown option:|^Value .*? for option |Option .* does not take an argument/) {
             # Getopt::Long warnings we promoted in _getopt_spec_warnings
             s/\n+$//;
             $class->getopt_usage( exit => 3, err => $_ );
         }
-        default {
+        else {
             die $_;
         }
     };
@@ -104,7 +104,7 @@ MooseX::Getopt::Usage - Extend MooseX::Getopt with usage message and man page ge
 
 =head1 VERSION
 
-Version 0.12
+Version 0.14
 
 =head1 SYNOPSIS
 
@@ -255,7 +255,11 @@ Display the man page instead of the usage message.
 =head2 getopt_usage_config
 
 Return a hash (ie a list) of config to override the defaults. Default returns
-empty list. See L</CONFIGURATION> for details.
+empty list. See L</CONFIGURATION> for details of the option keys.
+
+Note that this method gets called as a class method, before the class is
+constructed. If you wish to change this method from a role you will need to use
+the around method modifier. See L</Sharing config>.
 
 =head1 CONFIGURATION
 
@@ -452,7 +456,7 @@ Put this is a file called hello.pl and make it executable.
 
  #!/usr/bin/env perl
  package Hello;
- use Modern::Perl;
+ use 5.010;
  use Moose;
 
  with 'MooseX::Getopt::Usage';
@@ -495,6 +499,46 @@ Which will look a bit like this, only in colour.
           --verbose         - Bool. Say lots about what we do
           --greet           - Str. Default=World. Who to say hello to.
 
+=head2 Sharing config
+
+You may find that you want to have a common set of config (ie
+L</getopt_usage_config> return) shared by a number of command classes. You could
+do this with a common base class or as this is Moose do it with a role.
+
+First create the role class to hold the common config:
+
+    package CommonGetoptConfig;
+    use Moose::Role;
+
+    around getopt_usage_config => sub {
+        my $orig  = shift;
+        my $class = shift;
+        return (
+            attr_sort => sub { $_[0]->name cmp $_[1]->name },
+            format => "Usage: %c [OPTIONS]",
+            headings => 0,
+            $class->$orig(@_),
+        );
+    };
+
+    1;
+
+Then in you comand class consume that role:
+
+    #!/usr/bin/env perl
+    package Hello;
+    use Moose;
+   
+    with 'MooseX::Getopt::Usage';
+    with 'CommonGetoptConfig';
+   
+    #...
+
+Note that if the consuming class also impliments getopt_usage_config then
+the configs will be combined, with config from the class overriding that from
+the role. You can change this order by moving the C<< $class->$orig(@_), >> in
+the return in the role above.
+
 
 =head1 SEE ALSO
 
@@ -524,6 +568,13 @@ Mark Pitchless, C<< <markpitchless at gmail.com> >>
 
 =head1 ACKNOWLEDGEMENTS
 
+Wayne Marquette for bug finding and pushing the use cases.
+
+ilmari+cpan@ilmari.org for patching file based tests.
+
+Tomas Doran for discussions and ideas that lead to all the pod mangling
+goodness and the big refactor at version 0.09.
+
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2012 Mark Pitchless
