@@ -12,12 +12,20 @@ use Test::Differences;
 use FindBin qw($Bin);
 our $TBin = "$Bin/bin";
 
+# Grab the perl exe we are running under as recommended here:
+# http://wiki.cpantesters.org/wiki/CPANAuthorNotes
+# We need to run the test scripts under this perl to get the right includes in
+# automated environmenst like cpan testers running perlbrew.
+use Config;
+our $PerlPath = $Config{perlpath};
+
 sub cmd_stdout_like {
     my $cmd  = shift;
     my $re   = shift;
-    my $tname = shift || "$cmd; stdout like $re";
+    my $tname = shift || "@$cmd; stdout like $re";
+    my ($script, @args) = @{$cmd};
 
-    my ($stdout, $stderr) = capture { system("$TBin/$cmd") };
+    my ($stdout, $stderr) = capture { system($PerlPath, "$TBin/$script", @args) };
     like $stdout, $re, $tname;
 }
 
@@ -56,14 +64,26 @@ sub err_message : Test(1) {
 }
 
 # Are we trapping command line errors properly. ie in new_with_options
-sub cmd_line_errors : Tests(2) {
+sub cmd_line_errors : Tests(5) {
     my $self = shift;
 
-    cmd_stdout_like 'basic --notanoption',
+    cmd_stdout_like [qw'errors.pl --notanoption'],
         qr/^Unknown option: notanoption\nUsage/;
-    cmd_stdout_like 'basic --verbose=2',
+
+    cmd_stdout_like [qw'errors.pl --verbose=2'],
         qr/^Option verbose does not take an argument\nUsage/;
 
+    cmd_stdout_like [qw'required.pl'],
+        qr/^Required option missing: doom\nUsage/;
+
+    # This trips the getopt validation, not the moose type constraint
+    cmd_stdout_like [qw'errors.pl --doom=lots'],
+        qr/^Value "lots" invalid for option doom \(number expected\)\nUsage/;
+
+    # This gets past getopt but trips a moose type constraint
+    cmd_stdout_like [qw'errors.pl --missile_launchers=fast'],
+        qr/^Invalid 'missile_launchers' : value 'fast' is not one of on,off,auto\nUsage/;
+
     # TODO : Test all the error traps and test status code.
 }
 
